@@ -3,7 +3,7 @@ import os
 from logger_local.LoggerComponentEnum import LoggerComponentEnum
 
 PYTHON_SDK_LOCAL_COMPONENT_ID = 184
-PYTHON_SDK_LOCAL_COMPONENT_NAME = 'python_sdk_local'
+PYTHON_SDK_LOCAL_COMPONENT_NAME = 'python_sdk_remote'
 
 ENVIRONMENT_NAME = os.getenv("ENVIRONMENT_NAME")
 BRAND_NAME = os.getenv("BRAND_NAME")
