@@ -10,7 +10,12 @@ from .http_response import (create_authorization_http_headers, get_user_jwt_from
 from .mini_logger import MiniLogger as logger
 
 load_dotenv()
+# raise Exception("Failed to load environment variables from .env file\n"
+#                 "Please check if the file exists, maybe you are not in the right venv?")
 
+# TODO: add cache with/out timeout decorator
+
+DEFAULT_LANG_CODE_STR = "en"
 
 def timedelta_to_time_format(time_delta: timedelta) -> str:
     """
